@@ -1,12 +1,13 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1614 2018-01-15 13:48:42Z willem $
+# $Id: SEC.pm 1617 2018-01-22 08:57:39Z willem $
 #
 our $VERSION;
-$VERSION = '1.03_01';
-$VERSION = eval( my $SO_VERSION = $VERSION );
-our $SVNVERSION = (qw$LastChangedRevision: 1614 $)[1];
+$VERSION = '1.03_02';
+our $SVNVERSION = (qw$LastChangedRevision: 1617 $)[1];
+our $XS_VERSION = $VERSION;
+$VERSION = eval($VERSION);
 
 
 =head1 NAME
@@ -33,7 +34,7 @@ Net::DNS::SEC in the use declaration.
 
 
 use strict;
-use base qw(Exporter);
+use base qw(Exporter DynaLoader);
 
 use Net::DNS 1.01 qw(:DEFAULT);
 
@@ -44,23 +45,14 @@ use integer;
 use warnings;
 use Carp;
 
-use Net::DNS::RR::CDS;
-use Net::DNS::RR::DLV;
-use Net::DNS::RR::DS;
-use Net::DNS::RR::RRSIG;
-use Net::DNS::RR::SIG;
+Net::DNS::SEC->bootstrap($XS_VERSION);
 
 
-use constant XSLOADER => defined eval 'require XSLoader';
-
-XSLoader::load( 'Net::DNS::SEC', $SO_VERSION ) if XSLOADER;
-
-unless (XSLOADER) {
-	require DynaLoader;
-	our @ISA;
-	local @ISA = qw(DynaLoader);
-	Net::DNS::SEC->bootstrap($SO_VERSION);
-}
+require Net::DNS::RR::CDS;
+require Net::DNS::RR::DLV;
+require Net::DNS::RR::DS;
+require Net::DNS::RR::RRSIG;
+require Net::DNS::RR::SIG;
 
 
 =head1 UTILITY FUNCTIONS
@@ -128,12 +120,6 @@ sub key_difference {
 __END__
 
 
-=head1 ACKNOWLEDGEMENT
-
-Thanks are due to Eric Young and the many developers and contributors
-to the OpenSSL project and cryptographic library.
-
-
 =head1 COPYRIGHT
 
 Copyright (c)2014-2018 Dick Franks
