@@ -1,9 +1,9 @@
 package Net::DNS::SEC::DSA;
 
 #
-# $Id: DSA.pm 1613 2018-01-15 13:47:13Z willem $
+# $Id: DSA.pm 1616 2018-01-22 08:54:52Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1613 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1616 $)[1];
 
 
 =head1 NAME
@@ -69,17 +69,19 @@ sub sign {
 	my $q = decode_base64 $private->subprime;
 	my $g = decode_base64 $private->base;
 	my $x = decode_base64 $private->private_value;
+	my $y = decode_base64 $private->public_value;
 
 	Net::DNS::SEC::libcrypto::DSA_set0_pqg( $dsa, $p, $q, $g );
-	Net::DNS::SEC::libcrypto::DSA_set_priv_key( $dsa, $x );
+	Net::DNS::SEC::libcrypto::DSA_set0_key( $dsa, $y, $x );
 
 	my $sig = Net::DNS::SEC::libcrypto::DSA_do_sign( $hash->digest, $dsa );
 
-	Net::DNS::SEC::libcrypto::DSA_free($dsa);
+	$x = $q;						# destroy private key
+	Net::DNS::SEC::libcrypto::DSA_free($dsa);		# destroy private key
 
 	my $t = ( length($g) - 64 ) / 8;
-	my $r = Net::DNS::SEC::libcrypto::DSA_SIG_get_r($sig);
-	my $s = Net::DNS::SEC::libcrypto::DSA_SIG_get_s($sig);
+	return unless $sig;					# uncoverable branch
+	my ( $r, $s ) = Net::DNS::SEC::libcrypto::DSA_SIG_get0($sig);
 
 	Net::DNS::SEC::libcrypto::DSA_SIG_free($sig);
 
@@ -101,15 +103,14 @@ sub verify {
 
 	my $keybin = $keyrr->keybin;				# public key
 	my $numlen = 64 + 8 * unpack( 'C', $keybin );		# RFC2536, section 2
-	my ( $Q, $P, $G, $Y ) = unpack "x a20 a$numlen a$numlen a$numlen", $keybin;
+	my ( $q, $p, $g, $y ) = unpack "x a20 a$numlen a$numlen a$numlen", $keybin;
 
 	my $dsa = Net::DNS::SEC::libcrypto::DSA_new();
 
-	Net::DNS::SEC::libcrypto::DSA_set0_pqg( $dsa, $P, $Q, $G );
+	Net::DNS::SEC::libcrypto::DSA_set0_pqg( $dsa, $p, $q, $g );
+	Net::DNS::SEC::libcrypto::DSA_set0_key( $dsa, $y, '' );
 
-	Net::DNS::SEC::libcrypto::DSA_set_pub_key( $dsa, $Y );
-
-	my ( $r, $s ) = unpack 'x a20 a20', $sigbin;		# RFC2536, section 3
+	my ( $r, $s ) = unpack 'x a20 a20', $sigbin || return;	# RFC2536, section 3
 	my $dsasig = Net::DNS::SEC::libcrypto::DSA_SIG_new();
 	Net::DNS::SEC::libcrypto::DSA_SIG_set0( $dsasig, $r, $s );
 
@@ -127,6 +128,12 @@ __END__
 
 ########################################
 
+=head1 ACKNOWLEDGMENT
+
+Thanks are due to Eric Young and the many developers and 
+contributors to the OpenSSL cryptographic library.
+
+
 =head1 COPYRIGHT
 
 Copyright (c)2014,2018 Dick Franks.
